yt.frontends.owls.owls\_ion\_tables module
==========================================

.. automodule:: yt.frontends.owls.owls_ion_tables
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
